# Lancez-vous !

Bienvenue chez OpenSesame ! Que puis-je pour vous ?

<table><tr><td>

Commencer avec une nouvelle expérience :<br />
%(templates)s

</td><td>

%(recent_experiments)s

</td></tr></table>

Avez-vous pensé à faire un don à OpenSesame ? C'est facile et rapide.

[Faire un don par PayPal](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=QEWKSAY4WMKRW){: .important-button}

Ou en savoir plus :

[Lire la documentation](http://osdoc.cogsci.nl){: .button}<br />
[Poser une question sur le forum](http://forum.cogsci.nl){: .button}<br />
